summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/apr_uri.h30
-rw-r--r--uri/apr_uri.c14
2 files changed, 22 insertions, 22 deletions
diff --git a/include/apr_uri.h b/include/apr_uri.h
index b1658e7d..2e70f97f 100644
--- a/include/apr_uri.h
+++ b/include/apr_uri.h
@@ -103,12 +103,12 @@ extern "C" {
#define APR_URI_UNP_OMITPATHINFO (1U<<4) /* Show "scheme://user@site:port" only */
#define APR_URI_UNP_OMITQUERY (1U<<5) /* Omit the "?queryarg" from the path */
-typedef struct apr_uri_components apr_uri_components;
+typedef struct apr_uri_t apr_uri_t;
/**
* A structure to encompass all of the fields in a uri
*/
-struct apr_uri_components {
+struct apr_uri_t {
/** scheme ("http"/"ftp"/...) */
char *scheme;
/** combined [user[:password]@]host[:port] */
@@ -155,7 +155,7 @@ struct apr_uri_components {
APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
/**
* Unparse a apr_uri_components structure to an URI string. Optionally
* suppress the password for security reasons.
* @param p The pool to allocate out of
* @param uptr All of the parts of the uri
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
* APR_URI_UNP_OMITQUERY Omit the "?queryarg" from the path
* </PRE>
* @return The uri as a string
* @deffunc char * apr_uri_unparse_components(apr_pool_t *p, const apr_uri_components *uptr, unsigned flags)
*/
-APU_DECLARE(char *) apr_uri_unparse_components(apr_pool_t *p,
- const apr_uri_components *uptr,
+APU_DECLARE(char *) apr_uri_unparse(apr_pool_t *p,
+ const apr_uri_t *uptr,
unsigned flags);
/**
* Parse a given URI, fill in all supplied fields of a apr_uri_components
* structure. This eliminates the necessity of extracting host, port,
* path, query info repeatedly in the modules.
* @param p The pool to allocate out of
* @param uri The uri to parse
* @param uptr The apr_uri_components to fill out
* @return An HTTP status code
* @deffunc int apr_uri_parse_components(apr_pool_t *p, const char *uri, apr_uri_components *uptr)
*/
-APU_DECLARE(int) apr_uri_parse_components(apr_pool_t *p, const char *uri,
- apr_uri_components *uptr);
+APU_DECLARE(int) apr_uri_parse(apr_pool_t *p, const char *uri,
+ apr_uri_t *uptr);
/**
* Special case for CONNECT parsing: it comes with the hostinfo part only
* @param p The pool to allocate out of
* @param hostinfo The hostinfo string to parse
* @param uptr The apr_uri_components to fill out
* @return An HTTP status code
* @deffunc int apr_parse_hostinfo_components(apr_pool_t *p, const char *hostinfo, apr_uri_components *uptr)
*/
-APU_DECLARE(int) apr_uri_parse_hostinfo_components(apr_pool_t *p,
+APU_DECLARE(int) apr_uri_parse_hostinfo(apr_pool_t *p,
const char *hostinfo,
- apr_uri_components *uptr);
+ apr_uri_t *uptr);
#ifdef __cplusplus
}
@@ -155,7 +155,7 @@ struct apr_uri_components {
APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
/**
- * Unparse a apr_uri_components structure to an URI string. Optionally
+ * Unparse a apr_uri_t structure to an URI string. Optionally
* suppress the password for security reasons.
* @param p The pool to allocate out of
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
* </PRE>
* @return The uri as a string
- * @deffunc char * apr_uri_unparse_components(apr_pool_t *p, const apr_uri_components *uptr, unsigned flags)
+ * @deffunc char * apr_uri_unparse(apr_pool_t *p, const apr_uri_t *uptr, unsigned flags)
*/
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
unsigned flags);
/**
- * Parse a given URI, fill in all supplied fields of a apr_uri_components
+ * Parse a given URI, fill in all supplied fields of a apr_uri_t
* structure. This eliminates the necessity of extracting host, port,
* path, query info repeatedly in the modules.
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
* @param p The pool to allocate out of
* @param uri The uri to parse
- * @param uptr The apr_uri_components to fill out
+ * @param uptr The apr_uri_t to fill out
* @return An HTTP status code
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
* @return An HTTP status code
- * @deffunc int apr_uri_parse_components(apr_pool_t *p, const char *uri, apr_uri_components *uptr)
+ * @deffunc int apr_uri_parse(apr_pool_t *p, const char *uri, apr_uri_t *uptr)
*/
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
* @param p The pool to allocate out of
* @param hostinfo The hostinfo string to parse
- * @param uptr The apr_uri_components to fill out
+ * @param uptr The apr_uri_t to fill out
* @return An HTTP status code
@@ -170,36 +170,36 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str);
* @return An HTTP status code
- * @deffunc int apr_parse_hostinfo_components(apr_pool_t *p, const char *hostinfo, apr_uri_components *uptr)
+ * @deffunc int apr_parse_hostinfo_components(apr_pool_t *p, const char *hostinfo, apr_uri_t *uptr)
*/
diff --git a/uri/apr_uri.c b/uri/apr_uri.c
index 29bb66b8..7e181f11 100644
--- a/uri/apr_uri.c
+++ b/uri/apr_uri.c
@@ -119,11 +119,11 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str)
return 0;
}
/* Unparse a apr_uri_components structure to an URI string.
* Optionally suppress the password for security reasons.
*/
-APU_DECLARE(char *) apr_uri_unparse_components(apr_pool_t *p,
- const apr_uri_components *uptr,
+APU_DECLARE(char *) apr_uri_unparse(apr_pool_t *p,
+ const apr_uri_t *uptr,
unsigned flags)
{
char *ret = "";
@@ -217,8 +217,8 @@ APU_DECLARE(char *) apr_uri_unparse_components(apr_pool_t *p,
* - fills in fields of uri_components *uptr
* - none on any of the r->* fields
*/
-APU_DECLARE(int) apr_uri_parse_components(apr_pool_t *p, const char *uri,
- apr_uri_components *uptr)
+APU_DECLARE(int) apr_uri_parse(apr_pool_t *p, const char *uri,
+ apr_uri_t *uptr)
{
const char *s;
const char *s1;
@@ -342,9 +342,9 @@ deal_with_host:
* currently at http://www.mcom.com/newsref/std/tunneling_ssl.html
* for the format of the "CONNECT host:port HTTP/1.0" request
*/
-APU_DECLARE(int) apr_uri_parse_hostinfo_components(apr_pool_t *p,
+APU_DECLARE(int) apr_uri_parse_hostinfo(apr_pool_t *p,
const char *hostinfo,
- apr_uri_components *uptr)
+ apr_uri_t *uptr)
{
const char *s;
char *endstr;
@@ -119,11 +119,11 @@ APU_DECLARE(apr_port_t) apr_uri_default_port_for_scheme(const char *scheme_str)
return 0;
}
-/* Unparse a apr_uri_components structure to an URI string.
+/* Unparse a apr_uri_t structure to an URI string.
* Optionally suppress the password for security reasons.
*/